@@ -1,5 +1,5 @@
-use crate::western_musicbox::WesternMusicBox;
-use crate::semitone;
+use crate::core::MusicBox;
+use crate::core::semitone;
 
 /// Tuning, is a vector of string tonics <f64>
 /// Tones wrapping vector is a single string and starting at index 0 gives the tonic and successive semitones[frets]
@@ -7,7 +7,6 @@ use crate::semitone;
 pub struct Guitar{
  
     tuning: Vec<f64>,
-    
     tones: Vec<Vec<f64>>,
 
     }
@@ -16,13 +15,13 @@ pub struct Guitar{
  impl Guitar {
      ///Uses western music box to get notes, so adjust crate::TONIC for different
      pub fn standard_tuning() -> Self {
-          let music = WesternMusicBox::new();
-          let e = music.notes.get("E1").unwrap(); //Use of closures here in .map() do anything for me?
-          let a = music.notes.get("A2").unwrap();
-          let d = music.notes.get("D2").unwrap();
-          let g = music.notes.get("G2").unwrap();
-          let b = music.notes.get("B3").unwrap();
-          let high_e = music.notes.get("E3").unwrap();
+          let music = MusicBox::new();
+          let e = music.notary.get("E1").unwrap(); //Use of closures here in .map() do anything for me?
+          let a = music.notary.get("A2").unwrap();
+          let d = music.notary.get("D2").unwrap();
+          let g = music.notary.get("G2").unwrap();
+          let b = music.notary.get("B3").unwrap();
+          let high_e = music.notary.get("E3").unwrap();
           let tuning = vec![*e, *a, *d, *g, *b, *high_e];
           let mut tones = vec![];
           for i in 0..tuning.len(){
@@ -43,6 +42,7 @@ pub struct Guitar{
      }
      }
 
+
      }
  
 
