@@ -1,11 +1,17 @@
-use crate::interval::Interval;
-use Interval::{Semitone, Three4tone, Wholetone};
+use crate::notation::zoot_allures::Notation;
+use Notation::{Z1,Z3};
+
+use Notation::Z2;
+use Notation::ZQ;
+
+
 
 /// Is a series of trichords, tetrachords, and/or pentachords which
 /// Makam compose scales
+#[derive(Default)]
 pub struct Makam {
-    pub djin: Vec<Interval>,
-    pub scale: Vec<Interval>,
+    pub djin: Vec<Notation>,
+    pub scale: Vec<Notation>,
 }
 
 impl Makam {
@@ -16,19 +22,19 @@ impl Makam {
         }
     }
     pub fn cargah(&mut self) {
-        self.djin = vec![Wholetone, Wholetone, Semitone, Wholetone];
+        self.djin = vec![Z2, Z2, Z1, Z2];
     }
     pub fn kurdi(&mut self) {
-        self.djin = vec![Semitone, Wholetone, Wholetone];
+        self.djin = vec![Z1, Z2, Z3];
     }
     pub fn rast(&mut self) {
-        self.djin = vec![Wholetone, Three4tone, Three4tone, Wholetone];
+        self.djin = vec![Z2, ZQ, ZQ, Z2];
     }
     pub fn ussak(&mut self) {
-        self.djin = vec![Three4tone, Wholetone, Semitone, Wholetone];
+        self.djin = vec![ZQ, Z2, Z1, Z2];
     }
     pub fn hicaz(&mut self) {
-        self.djin = vec![Wholetone, Wholetone, Semitone, Wholetone];
+        self.djin = vec![Z2, Z2, Z1, Z2];
     }
 }
 
@@ -36,5 +42,5 @@ impl Makam {
 fn get_djin_cargah() {
     let mut cargah = Makam::new();
     cargah.cargah();
-    assert_eq!(cargah.djin[1], Wholetone);
+    assert_eq!(cargah.djin[1], Z2);
 }
