@@ -1,10 +1,10 @@
 #[test]
-fn main() {
-    use musicbox::western_musicbox::WesternMusicBox;
-    let mut music = WesternMusicBox::new();
+fn chord_abstraction() {
+    use musicbox::MusicBox;
+    let mut music = MusicBox::new();
 
     let a_major_0 = music
-        .notes
+        .notary
         .retain(|k, _| k == "A0" && k == "Db0" && k == "E0");
     assert!(a_major_0 != ()) //FAILS!
 }
